@@ -9,12 +9,15 @@ class ApiSettings(pydantic.BaseSettings):
     name: str = "titiler"
     cors_origins: str = "*"
     cachecontrol: str = "public, max-age=3600"
+    root_path: str = ""
     debug: bool = False
 
     disable_cog: bool = False
     disable_stac: bool = False
     disable_mosaic: bool = False
 
+    lower_case_query_parameters: bool = False
+
     @pydantic.validator("cors_origins")
     def parse_cors_origin(cls, v):
         """Parse CORS origins."""
